gedidb.L2AGranule
=================

.. currentmodule:: gedidb

.. autoclass:: L2AGranule

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~L2AGranule.__init__
      ~L2AGranule.beam
      ~L2AGranule.build_virtual_dataset
      ~L2AGranule.clear
      ~L2AGranule.close
      ~L2AGranule.copy
      ~L2AGranule.create_dataset
      ~L2AGranule.create_dataset_like
      ~L2AGranule.create_group
      ~L2AGranule.create_virtual_dataset
      ~L2AGranule.flush
      ~L2AGranule.get
      ~L2AGranule.items
      ~L2AGranule.iter_beams
      ~L2AGranule.keys
      ~L2AGranule.list_beams
      ~L2AGranule.move
      ~L2AGranule.pop
      ~L2AGranule.popitem
      ~L2AGranule.require_dataset
      ~L2AGranule.require_group
      ~L2AGranule.setdefault
      ~L2AGranule.update
      ~L2AGranule.validate_beam_name
      ~L2AGranule.values
      ~L2AGranule.visit
      ~L2AGranule.visit_links
      ~L2AGranule.visititems
      ~L2AGranule.visititems_links
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~L2AGranule.abstract
      ~L2AGranule.attrs
      ~L2AGranule.driver
      ~L2AGranule.file
      ~L2AGranule.filename
      ~L2AGranule.filename_metadata
      ~L2AGranule.id
      ~L2AGranule.libver
      ~L2AGranule.meta_block_size
      ~L2AGranule.mode
      ~L2AGranule.n_beams
      ~L2AGranule.name
      ~L2AGranule.parent
      ~L2AGranule.product
      ~L2AGranule.ref
      ~L2AGranule.regionref
      ~L2AGranule.start_datetime
      ~L2AGranule.swmr_mode
      ~L2AGranule.userblock_size
      ~L2AGranule.uuid
      ~L2AGranule.version_granule
      ~L2AGranule.version_product
   
   